# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import peacemakr
from peacemakr.generated.api.key_service_api import KeyServiceApi  # noqa: E501
from peacemakr.generated.rest import ApiException


class TestKeyServiceApi(unittest.TestCase):
    """KeyServiceApi unit test stubs"""

    def setUp(self):
        self.api = peacemakr.generated.api.key_service_api.KeyServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_encrypted_keys(self):
        """Test case for get_all_encrypted_keys

        Get all encrypted symmetric keys that are encrypted with this encrypting keyId, optionally limiting the request to a set of symmetric key domains  # noqa: E501
        """
        pass

    def test_get_public_key(self):
        """Test case for get_public_key

        Get the public key associated with the passed-in key ID  # noqa: E501
        """
        pass

    def test_post_new_encrypted_keys(self):
        """Test case for post_new_encrypted_keys

        Add a new encrypted key. The encrypting key that protects the encrypted key is identified with encryptingKeyId. Request must come from a registered key manager.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
