# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import peacemakr
from peacemakr.generated.api.org_api import OrgApi  # noqa: E501
from peacemakr.generated.rest import ApiException


class TestOrgApi(unittest.TestCase):
    """OrgApi unit test stubs"""

    def setUp(self):
        self.api = peacemakr.generated.api.org_api.OrgApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_admin_to_org(self):
        """Test case for add_admin_to_org

        Add a new admin to this org  # noqa: E501
        """
        pass

    def test_add_api_key_to_org(self):
        """Test case for add_api_key_to_org

        Add a new API Key to an org  # noqa: E501
        """
        pass

    def test_add_organization(self):
        """Test case for add_organization

        Create a new organization. Must be an authenticated request with a valid id_token from a trusted IdP.  # noqa: E501
        """
        pass

    def test_delete_admin_from_org(self):
        """Test case for delete_admin_from_org

        Remove an existing admin from the org (You can not remove the last admin. It will faile with a Bad Request response.)  # noqa: E501
        """
        pass

    def test_delete_api_key_from_org(self):
        """Test case for delete_api_key_from_org

        Remove an existing API Key  # noqa: E501
        """
        pass

    def test_delete_organization(self):
        """Test case for delete_organization

        Remove an existing organization  # noqa: E501
        """
        pass

    def test_get_cloud_organization_api_key(self):
        """Test case for get_cloud_organization_api_key

        Get an access key for the peacemakr shared cloud org (all cloud key derivers must use this)  # noqa: E501
        """
        pass

    def test_get_organization(self):
        """Test case for get_organization

        Get an existing organization  # noqa: E501
        """
        pass

    def test_get_organization_from_api_key(self):
        """Test case for get_organization_from_api_key

        Get an existing Organization  # noqa: E501
        """
        pass

    def test_get_test_organization_api_key(self):
        """Test case for get_test_organization_api_key

        Get an ephemeral test org api key  # noqa: E501
        """
        pass

    def test_update_stripe_customer_id(self):
        """Test case for update_stripe_customer_id

        Update the stripe customer Id associated with this account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
