# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import peacemakr
from peacemakr.generated.api.key_derivation_service_registry_api import KeyDerivationServiceRegistryApi  # noqa: E501
from peacemakr.generated.rest import ApiException


class TestKeyDerivationServiceRegistryApi(unittest.TestCase):
    """KeyDerivationServiceRegistryApi unit test stubs"""

    def setUp(self):
        self.api = peacemakr.generated.api.key_derivation_service_registry_api.KeyDerivationServiceRegistryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_key_derivation_service_instance(self):
        """Test case for add_key_derivation_service_instance

        Register a new KeyDerivationServiceInstance  # noqa: E501
        """
        pass

    def test_delete_key_derivation_service_instance(self):
        """Test case for delete_key_derivation_service_instance

        Activate or deactivate an existing KeyDerivationServiceInstance  # noqa: E501
        """
        pass

    def test_get_all_org_key_derivation_service_instances(self):
        """Test case for get_all_org_key_derivation_service_instances

        Get the all key derivers registerd to org  # noqa: E501
        """
        pass

    def test_get_all_shared_key_derivation_service_instances(self):
        """Test case for get_all_shared_key_derivation_service_instances

        Get the all key derivers that the org has access to - including shared cloud instances  # noqa: E501
        """
        pass

    def test_get_key_derivation_service_instance(self):
        """Test case for get_key_derivation_service_instance

        Get the keyderiver details by id  # noqa: E501
        """
        pass

    def test_heartbeat_key_derivation_service_instance(self):
        """Test case for heartbeat_key_derivation_service_instance

        Heatbeat from the given key derivation service instance  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
