# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import peacemakr
from peacemakr.generated.api.server_management_api import ServerManagementApi  # noqa: E501
from peacemakr.generated.rest import ApiException


class TestServerManagementApi(unittest.TestCase):
    """ServerManagementApi unit test stubs"""

    def setUp(self):
        self.api = peacemakr.generated.api.server_management_api.ServerManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_health_get(self):
        """Test case for health_get

        See if the server is healthy  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
