# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import peacemakr
from peacemakr.generated.api.crypto_config_api import CryptoConfigApi  # noqa: E501
from peacemakr.generated.rest import ApiException


class TestCryptoConfigApi(unittest.TestCase):
    """CryptoConfigApi unit test stubs"""

    def setUp(self):
        self.api = peacemakr.generated.api.crypto_config_api.CryptoConfigApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_existing_use_domain(self):
        """Test case for add_existing_use_domain

        Add an existing use domain to another crypto config.  # noqa: E501
        """
        pass

    def test_add_use_domain(self):
        """Test case for add_use_domain

        Add a new active use domain and attached it to the crypto config.  # noqa: E501
        """
        pass

    def test_get_crypto_config(self):
        """Test case for get_crypto_config

        Get the crypto configurations  # noqa: E501
        """
        pass

    def test_rapid_rotation_use_domain(self):
        """Test case for rapid_rotation_use_domain

        Rapid expiration of existing use doamin and immediately replacment with an identical use domain containing fresh keys  # noqa: E501
        """
        pass

    def test_remove_use_domain(self):
        """Test case for remove_use_domain

        Delete a fully expired use domain  # noqa: E501
        """
        pass

    def test_update_crypto_config(self):
        """Test case for update_crypto_config

        Update the crypto configuration, ONLY the clientKeyType clientKeyBitlength, and clientKeyTTL fields.  # noqa: E501
        """
        pass

    def test_update_crypto_config_fallback_to_cloud(self):
        """Test case for update_crypto_config_fallback_to_cloud

        Update an existing crypto config's asymmetricKeyTTL  # noqa: E501
        """
        pass

    def test_update_crypto_config_selector_scheme(self):
        """Test case for update_crypto_config_selector_scheme

        Update an existing crypto config's domainSelectorScheme  # noqa: E501
        """
        pass

    def test_update_expire_use_domain(self):
        """Test case for update_expire_use_domain

        Chnage expiration of a use domain  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
